Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(319)

Unified Diff: remoting/host/video_scheduler.cc

Issue 810133003: replace NULL->nullptr in src/remoting. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/video_frame_recorder.cc ('k') | remoting/host/video_scheduler_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/video_scheduler.cc
diff --git a/remoting/host/video_scheduler.cc b/remoting/host/video_scheduler.cc
index f2ded2069352d745a6af899f412e763a9699e7c8..e2a3f945533aec44f68f2d58c1860f07494e90a5 100644
--- a/remoting/host/video_scheduler.cc
+++ b/remoting/host/video_scheduler.cc
@@ -76,7 +76,7 @@ VideoScheduler::VideoScheduler(
// Public methods --------------------------------------------------------------
webrtc::SharedMemory* VideoScheduler::CreateSharedMemory(size_t size) {
- return NULL;
+ return nullptr;
}
void VideoScheduler::OnCaptureCompleted(webrtc::DesktopFrame* frame) {
@@ -91,7 +91,7 @@ void VideoScheduler::OnCaptureCompleted(webrtc::DesktopFrame* frame) {
base::TimeDelta::FromMilliseconds(owned_frame->capture_time_ms()));
}
// Even when |frame| is NULL we still need to post it to the encode thread
// to make sure frames are freed in the same order they are received and
// that we don't start capturing frame n+2 before frame n is freed.
encode_task_runner_->PostTask(
@@ -155,8 +155,8 @@ void VideoScheduler::Stop() {
DCHECK(network_task_runner_->BelongsToCurrentThread());
// Clear stubs to prevent further updates reaching the client.
- cursor_stub_ = NULL;
- video_stub_ = NULL;
+ cursor_stub_ = nullptr;
+ video_stub_ = nullptr;
keep_alive_timer_.reset();
@@ -270,7 +270,7 @@ void VideoScheduler::ScheduleNextCapture() {
void VideoScheduler::CaptureNextFrame() {
DCHECK(capture_task_runner_->BelongsToCurrentThread());
// If we are stopping (|capturer_| is NULL), or paused, then don't capture.
if (!capturer_ || is_paused_)
return;
« no previous file with comments | « remoting/host/video_frame_recorder.cc ('k') | remoting/host/video_scheduler_unittest.cc » ('j') | no next file with comments »
@@ -91,7 +91,7 @@ void VideoScheduler::OnCaptureCompleted(webrtc::DesktopFrame* frame) {
base::TimeDelta::FromMilliseconds(owned_frame->capture_time_ms()));
}
- // Even when |frame| is NULL we still need to post it to the encode thread
+ // Even when |frame| is nullptr we still need to post it to the encode thread
// to make sure frames are freed in the same order they are received and
// that we don't start capturing frame n+2 before frame n is freed.
@@ -270,7 +270,7 @@ void VideoScheduler::ScheduleNextCapture() {
void VideoScheduler::CaptureNextFrame() {
DCHECK(capture_task_runner_->BelongsToCurrentThread());
- // If we are stopping (|capturer_| is NULL), or paused, then don't capture.
+ // If we are stopping (|capturer_| is nullptr), or paused, then don't capture.
if (!capturer_ || is_paused_)
return;

Powered by Google App Engine
This is Rietveld 408576698